@@ -11,17 +11,18 @@ typedef enum {
 	GO_ERROR
 } GOSeverity;
 
+GType      go_error_info_get_type (void);
 GOErrorInfo *go_error_info_new_str			(char const *msg);
 GOErrorInfo *go_error_info_new_printf		(char const *msg_format, ...) G_GNUC_PRINTF (1, 2);
 GOErrorInfo *go_error_info_new_vprintf		(GOSeverity severity,
 						 char const *msg_format,
-						 va_list args);
+						 va_list args) G_GNUC_PRINTF (2, 0);
 GOErrorInfo *go_error_info_new_str_with_details	(char const *msg, GOErrorInfo *details);
 GOErrorInfo *go_error_info_new_str_with_details_list (char const *msg, GSList *details);
 GOErrorInfo *go_error_info_new_from_error_list	(GSList *errors);
 GOErrorInfo *go_error_info_new_from_errno		(void);
 void	   go_error_info_add_details		(GOErrorInfo *error, GOErrorInfo *details);
-void	   go_error_info_add_details_list	  	(GOErrorInfo *error, GSList *details);
+void	   go_error_info_add_details_list	(GOErrorInfo *error, GSList *details);
 void	   go_error_info_free			(GOErrorInfo *error);
 void	   go_error_info_print			(GOErrorInfo *error);
 char const*go_error_info_peek_message		(GOErrorInfo *error);
